# -*- coding: utf-8 -*-
import logging

from django.conf import settings
from django.core.exceptions import ValidationError
from django.core.management.base import BaseCommand
from logging import StreamHandler

from thx.pg_history.utils import HistoryHelper


class Command(BaseCommand):
    help = "Sync external database history."
    logger = logging.getLogger('file')

    def add_arguments(self, parser):
        parser.add_argument(
            '-c', '--console', action='store_true', default=False,
            help='Debug - write logging to console',
        )
        parser.add_argument(
            '-l', '--debug-level', default='info',
            help='Set debug level (debug, info, warnings) for console',
        )

    def handle(self, *args, **options):
        try:
            debug_level = getattr(logging, options.get('debug_level').upper())
            self.logger.setLevel(debug_level)
            self.logger.handlers[0].setLevel(debug_level)

            if options.get('console'):
                console_handler = StreamHandler()
                console_handler.setLevel(debug_level)
                self.logger.addHandler(console_handler)
                self.logger.setLevel(debug_level)

            results = HistoryHelper().sync_history_tables()
            self.logger.info("Sync results %s", results)

        except Exception as e:
            self.stdout.write(self.style.ERROR(
                f'Execution failed: {e}')
            )
