# -*- coding: utf-8 -*-
import json
import pghistory

from django.core import serializers
from django.core.serializers.json import DjangoJSONEncoder
from django.db.models import ForeignKey


class HistoryModelMixin:
    """History mixin model."""


    def save(self, *args, **kwargs):
        with pghistory.context(**self.prepare_fk_context()):
            self._original_save(*args, **kwargs)

    def prepare_single_fk_context(self, instance, field):
        instance_fk = getattr(instance, field.name, None)
        if not instance_fk:
            return {}
        if hasattr(instance_fk, 'password'):
            instance_fk.password = None
        data = serializers.serialize("json", [instance_fk], cls=DjangoJSONEncoder)
        return json.loads(data)[0]

    def prepare_fk_context(self):
        fields = self.__class__._meta.get_fields()
        ctx = {
            field.name: self.prepare_single_fk_context(self, field) for field in fields if isinstance(field, ForeignKey)
        }
        return ctx
