# -*- coding: utf-8 -*-
from django.conf import settings


class BaseRouter:
    route_app_labels = {}
    database_name = None

    def db_for_read(self, model, **hints):
        if model._meta.app_label in self.route_app_labels:
            return self.database_name
        return None

    def db_for_write(self, model, **hints):
        if model._meta.app_label in self.route_app_labels:
            return self.database_name
        return None

    def allow_relation(self, obj1, obj2, **hints):
        if (
            obj1._meta.app_label in self.route_app_labels or
            obj2._meta.app_label in self.route_app_labels
        ):
            return True
        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):
        if app_label in self.route_app_labels:
            return db == self.database_name
        if db == self.database_name:
            return False
        return None


class HistoryRouter(BaseRouter):
    route_app_labels = {settings.HISTORY_APP_NAME, 'pghistory'}
    database_name = 'default'

    def db_for_read(self, model, **hints):
        if model._meta.app_label in self.route_app_labels:
            return settings.HISTORY_DATABASE_NAME
        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):
        if app_label in self.route_app_labels:
            return db in [settings.HISTORY_DATABASE_NAME, self.database_name]
        if db == settings.HISTORY_DATABASE_NAME:
            return False
        return None
